%global srcname docx

# Currently, python-behave is not packaged for EPEL8.
%bcond_with behave

Name:           python-%{srcname}
Version:        0.8.11
%forgemeta
Release:        2%{?dist}
Summary:        Create and modify Word documents with Python

License:        MIT
URL:            https://%{name}.readthedocs.io/en/latest/
# We MUST use the PyPI tarball; the GitHub tarball includes material under ref/
# (PDFs of ISO/IEC standards) for which redistribution may be prohibited.
Source0:        %{pypi_source %{name}}

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  python3dist(setuptools)

# setup.py install_requires:
BuildRequires:  python3dist(lxml) >= 2.3.2

# tox.ini:
%if %{with behave}
BuildRequires:  python3dist(behave)
%endif
BuildRequires:  python3dist(pyparsing)
BuildRequires:  python3dist(pytest)

BuildRequires:  dos2unix

# Extra dependencies for documentation
BuildRequires:  make
BuildRequires:  python3dist(sphinx)
BuildRequires:  python3-docs
 
%global common_description %{expand:
A Python library for creating and updating Microsoft Word (.docx) files.}

%description %{common_description}


%package -n python3-%{srcname}
Summary:        %{summary}
%py_provides %{name}

%description -n python3-%{srcname} %{common_description}


%package        doc
Summary:        Documentation for %{name}

Requires:       python3-docs

%description    doc %{common_description}


%prep
%autosetup

# We don’t want to package https://github.com/armstrong/armstrong_sphinx (and
# shouldn’t use the bundled copy), so we just switch the documentation theme
# from “armstrong” to the built-in “alabaster”. The result seems similarly
# useful, without the bundling.
rm -rf docs/_themes
sed -r -i 's@armstrong@alabaster@' docs/conf.py

# Use local inventories in intersphinx mappings.
sed -r -i 's@https?://docs.python.org/3?@/%{_docdir}/python3-docs/html@' \
    docs/conf.py

# Fix a stray CRLF-terminated reStructuredText file:
dos2unix docs/dev/analysis/features/table/cell-merge.rst


%build
%py3_build

%make_build -C docs SPHINXOPTS='%{?_smp_mflags}'
rm -vf docs/.build/html/.buildinfo


%install
%py3_install


%check
export PYTHONPATH='%{buildroot}%{python3_sitelib}'
export PYTHONDONTWRITEBYTECODE='1'
%{__python3} -m pytest
%if %{with behave}
%{__python3} -m behave --format progress --stop --tags=-wip
%endif

# Fail the build if the tarball accidentally included ISO/IEC standards
# documents that should not have been redistributed. Note that removing these
# in %%prep would not have been good enough.
banned="$(find . -type f -name 'ISO*.pdf')"
if [ -n "${banned}" ]
then
  cat <<EOF
Source included ISO/IEC standards documents, which should not have been
redistributed:

${banned}
EOF
  exit 1
fi
if [ -e 'ref' ]
then
  cat <<EOF
Source had ref/ subdirectory, which has historically included content that
should not be redistributed.
EOF
  exit 1
fi


%files -n python3-%{srcname}
%license LICENSE
%{python3_sitelib}/%{srcname}
%{python3_sitelib}/python_docx-%{version}-py%{python3_version}.egg-info


%files doc
%license LICENSE
%doc HISTORY.rst
%doc README.rst
%doc docs/.build/html


%changelog
* Tue Aug 10 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.8.11-2
- Use the PyPI tarball to avoid redistributing ISO standard PDFs

* Fri Aug 06 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.8.11-1
- Initial package for EPEL8
